==> kubernetes-model-admissionregistration-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/ValidatingWebhookConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ValidatingWebhookConfigurationListFluent<A extends ValidatingWebhookConfigurationListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ValidatingWebhookConfiguration item);
    public A setToItems(int index,ValidatingWebhookConfiguration item);
    public A addToItems(ValidatingWebhookConfiguration... items);
    public A addAllToItems(Collection<ValidatingWebhookConfiguration> items);
    public A removeFromItems(ValidatingWebhookConfiguration... items);
    public A removeAllFromItems(Collection<ValidatingWebhookConfiguration> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ValidatingWebhookConfiguration> getItems();
    public List<ValidatingWebhookConfiguration> buildItems();
    public ValidatingWebhookConfiguration buildItem(int index);
    public ValidatingWebhookConfiguration buildFirstItem();
    public ValidatingWebhookConfiguration buildLastItem();
    public ValidatingWebhookConfiguration buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public A withItems(List<ValidatingWebhookConfiguration> items);
    public A withItems(ValidatingWebhookConfiguration... items);
    public Boolean hasItems();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItemLike(ValidatingWebhookConfiguration item);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,ValidatingWebhookConfiguration item);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editItem(int index);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editFirstItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editLastItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ValidatingWebhookConfigurationFluent<ValidatingWebhookConfigurationListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/ValidatingWebhookConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ValidatingWebhookConfigurationListFluent<A extends ValidatingWebhookConfigurationListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,ValidatingWebhookConfiguration item);
    public A setToItems(int index,ValidatingWebhookConfiguration item);
    public A addToItems(ValidatingWebhookConfiguration... items);
    public A addAllToItems(Collection<ValidatingWebhookConfiguration> items);
    public A removeFromItems(ValidatingWebhookConfiguration... items);
    public A removeAllFromItems(Collection<ValidatingWebhookConfiguration> items);
    public A removeMatchingFromItems(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ValidatingWebhookConfiguration> getItems();
    public List<ValidatingWebhookConfiguration> buildItems();
    public ValidatingWebhookConfiguration buildItem(int index);
    public ValidatingWebhookConfiguration buildFirstItem();
    public ValidatingWebhookConfiguration buildLastItem();
    public ValidatingWebhookConfiguration buildMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public A withItems(List<ValidatingWebhookConfiguration> items);
    public A withItems(ValidatingWebhookConfiguration... items);
    public Boolean hasItems();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItemLike(ValidatingWebhookConfiguration item);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,ValidatingWebhookConfiguration item);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editItem(int index);
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editFirstItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editLastItem();
    public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ValidatingWebhookConfigurationFluent<ValidatingWebhookConfigurationListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
